﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 텐션
        /// </summary>
        private float tension = 0.5f;

        /// <summary>
        /// 포인트 리스트
        /// </summary>
        private List<Point> pointList = new List<Point>();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 이벤트를 설정한다.

            MouseClick                  += Form_MouseClick;
            Paint                       += Form_Paint;
            this.newMenuItem.Click      += newMenuItem_Click;
            this.tensionTrackBar.Scroll += tensionTrackBar_Scroll;

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 마우스 클릭시 처리하기 - Form_MouseClick(sender, e)

        /// <summary>
        /// 폼 마우스 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_MouseClick(object sender, MouseEventArgs e)
        {
            this.pointList.Add(e.Location);

            Refresh();
        }

        #endregion
        #region 폼 페인트시 처리하기 - Form_Paint(sender, e)

        /// <summary>
        /// 폼 페인트시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Paint(object sender, PaintEventArgs e)
        {
            e.Graphics.SmoothingMode = SmoothingMode.AntiAlias;

            foreach(Point point in this.pointList)
            {
                e.Graphics.FillEllipse
                (
                    Brushes.Black,
                    point.X - 3,
                    point.Y - 3,
                    5,
                    5
                );
            }

            if(this.pointList.Count < 2)
            {
                return;
            }

            e.Graphics.DrawCurve(Pens.Red, this.pointList.ToArray(), this.tension);
        }

        #endregion
        #region 새로 그리기 메뉴 항목 클릭시 처리하기 - newMenuItem_Click(sender, e)

        /// <summary>
        /// 새로 그리기 메뉴 항목 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void newMenuItem_Click(object sender, EventArgs e)
        {
            this.pointList = new List<Point>();

            Refresh();
        }

        #endregion
        #region 텐션 트랙바 스크롤시 처리하기 - tensionTrackBar_Scroll(sender, e)

        /// <summary>
        /// 텐션 트랙바 스크롤시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void tensionTrackBar_Scroll(object sender, EventArgs e)
        {
            this.tension = this.tensionTrackBar.Value / 10f;

            this.tensionTextBox.Text = this.tension.ToString("0.0");

            Refresh();
        }

        #endregion
    }
}